//Source file: ChargingError.java
//Date: March 2007
//Charging Interfaces and Data Types for 3GPP TS 29.198-12 V7.0.0, Release 7

package org.csapi.jr.se.cs;

/**
 * Indicates the error that occurred.
 *
 */
public final class ChargingError implements java.io.Serializable {

    private int _value;
    private static int _size = 11;
    private static ChargingError[] _array = new ChargingError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private ChargingError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Generic error.
     */
    public static final int _CHS_ERR_UNDEFINED =  0;

    /**
     * Generic error.
     */
    public static final ChargingError CHS_ERR_UNDEFINED = new ChargingError(_CHS_ERR_UNDEFINED);

    /**
     * Merchant account unknown.
     */
    public static final int _CHS_ERR_ACCOUNT =  1;

    /**
     * Merchant account unknown.
     */
    public static final ChargingError CHS_ERR_ACCOUNT = new ChargingError(_CHS_ERR_ACCOUNT);

    /**
     * Unknown user.
     */
    public static final int _CHS_ERR_USER =  2;

    /**
     * Unknown user.
     */
    public static final ChargingError CHS_ERR_USER = new ChargingError(_CHS_ERR_USER);

    /**
     * The set of charging parameters contains an unknown parameter, or a required parameter is missing.
     */
    public static final int _CHS_ERR_PARAMETER =  3;

    /**
     * The set of charging parameters contains an unknown parameter, or a required parameter is missing.
     */
    public static final ChargingError CHS_ERR_PARAMETER = new ChargingError(_CHS_ERR_PARAMETER);

    /**
     * For some reason the application is not allowed to get money from this user.
     */
    public static final int _CHS_ERR_NO_DEBIT =  4;

    /**
     * For some reason the application is not allowed to get money from this user.
     */
    public static final ChargingError CHS_ERR_NO_DEBIT = new ChargingError(_CHS_ERR_NO_DEBIT);

    /**
     * For some reason the application is not allowed to pay this user.
     */
    public static final int _CHS_ERR_NO_CREDIT =  5;

    /**
     * For some reason the application is not allowed to pay this user.
     */
    public static final ChargingError CHS_ERR_NO_CREDIT = new ChargingError(_CHS_ERR_NO_CREDIT);

    /**
     * Required volumes are missing.
     */
    public static final int _CHS_ERR_VOLUMES =  6;

    /**
     * Required volumes are missing.
     */
    public static final ChargingError CHS_ERR_VOLUMES = new ChargingError(_CHS_ERR_VOLUMES);

    /**
     * This currency is not supported for this transaction.
     */
    public static final int _CHS_ERR_CURRENCY =  7;

    /**
     * This currency is not supported for this transaction.
     */
    public static final ChargingError CHS_ERR_CURRENCY = new ChargingError(_CHS_ERR_CURRENCY);

    /**
     * Request to extend the lifetime of a reservation is rejected.
     */
    public static final int _CHS_ERR_NO_EXTEND =  8;

    /**
     * Request to extend the lifetime of a reservation is rejected.
     */
    public static final ChargingError CHS_ERR_NO_EXTEND = new ChargingError(_CHS_ERR_NO_EXTEND);

    /**
     * This amount or volume violates the bounds of the reservation.
     */
    public static final int _CHS_ERR_RESERVATION_LIMIT =  9;

    /**
     * This amount or volume violates the bounds of the reservation.
     */
    public static final ChargingError CHS_ERR_RESERVATION_LIMIT = new ChargingError(_CHS_ERR_RESERVATION_LIMIT);

    /**
     * A user confirmation is required, but couldn't be obtained by the SCS. The SCS expects that the client initiates a stored confirmation scenario.
     */
    public static final int _CHS_ERR_CONFIRMATION_REQUIRED =  10;

    /**
     * A user confirmation is required, but couldn't be obtained by the SCS. The SCS expects that the client initiates a stored confirmation scenario.
     */
    public static final ChargingError CHS_ERR_CONFIRMATION_REQUIRED = new ChargingError(_CHS_ERR_CONFIRMATION_REQUIRED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved ChargingError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the ChargingError object
     */
    public String getValueText() {
        switch (_value) {
            case _CHS_ERR_UNDEFINED:
                return "CHS_ERR_UNDEFINED";
            case _CHS_ERR_ACCOUNT:
                return "CHS_ERR_ACCOUNT";
            case _CHS_ERR_USER:
                return "CHS_ERR_USER";
            case _CHS_ERR_PARAMETER:
                return "CHS_ERR_PARAMETER";
            case _CHS_ERR_NO_DEBIT:
                return "CHS_ERR_NO_DEBIT";
            case _CHS_ERR_NO_CREDIT:
                return "CHS_ERR_NO_CREDIT";
            case _CHS_ERR_VOLUMES:
                return "CHS_ERR_VOLUMES";
            case _CHS_ERR_CURRENCY:
                return "CHS_ERR_CURRENCY";
            case _CHS_ERR_NO_EXTEND:
                return "CHS_ERR_NO_EXTEND";
            case _CHS_ERR_RESERVATION_LIMIT:
                return "CHS_ERR_RESERVATION_LIMIT";
            case _CHS_ERR_CONFIRMATION_REQUIRED:
                return "CHS_ERR_CONFIRMATION_REQUIRED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 10
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static ChargingError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ChargingError)) {
            return false;
        }
        ChargingError chargingError = (ChargingError) o; 
        if(!(this.getValue() == chargingError.getValue())) {
            return false;
        }
        if (this.hashCode() != chargingError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ChargingError

