//Source file: ChargingParameterValueType.java
//Date: March 2007
//Charging Interfaces and Data Types for 3GPP TS 29.198-12 V7.0.0, Release 7

package org.csapi.jr.se.cs;

/**
 * Defines the type of charging parameter.
 *
 */
public final class ChargingParameterValueType implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static ChargingParameterValueType[] _array = new ChargingParameterValueType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private ChargingParameterValueType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Parameter represented by a TpInt32.
     */
    public static final int _CHS_PARAMETER_INT32 =  0;

    /**
     * Parameter represented by a TpInt32.
     */
    public static final ChargingParameterValueType CHS_PARAMETER_INT32 = new ChargingParameterValueType(_CHS_PARAMETER_INT32);

    /**
     * Parameter represented by a TpFloat.
     */
    public static final int _CHS_PARAMETER_FLOAT =  1;

    /**
     * Parameter represented by a TpFloat.
     */
    public static final ChargingParameterValueType CHS_PARAMETER_FLOAT = new ChargingParameterValueType(_CHS_PARAMETER_FLOAT);

    /**
     * Parameter represented by a TpString.
     */
    public static final int _CHS_PARAMETER_STRING =  2;

    /**
     * Parameter represented by a TpString.
     */
    public static final ChargingParameterValueType CHS_PARAMETER_STRING = new ChargingParameterValueType(_CHS_PARAMETER_STRING);

    /**
     * Parameter represented by a TpBoolean.
     */
    public static final int _CHS_PARAMETER_BOOLEAN =  3;

    /**
     * Parameter represented by a TpBoolean.
     */
    public static final ChargingParameterValueType CHS_PARAMETER_BOOLEAN = new ChargingParameterValueType(_CHS_PARAMETER_BOOLEAN);

    /**
     * Parameter represented by a TpOctetSet.
     */
    public static final int _CHS_PARAMETER_OCTETSET =  4;

    /**
     * Parameter represented by a TpOctetSet.
     */
    public static final ChargingParameterValueType CHS_PARAMETER_OCTETSET = new ChargingParameterValueType(_CHS_PARAMETER_OCTETSET);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved ChargingParameterValueType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the ChargingParameterValueType object
     */
    public String getValueText() {
        switch (_value) {
            case _CHS_PARAMETER_INT32:
                return "CHS_PARAMETER_INT32";
            case _CHS_PARAMETER_FLOAT:
                return "CHS_PARAMETER_FLOAT";
            case _CHS_PARAMETER_STRING:
                return "CHS_PARAMETER_STRING";
            case _CHS_PARAMETER_BOOLEAN:
                return "CHS_PARAMETER_BOOLEAN";
            case _CHS_PARAMETER_OCTETSET:
                return "CHS_PARAMETER_OCTETSET";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static ChargingParameterValueType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ChargingParameterValueType)) {
            return false;
        }
        ChargingParameterValueType chargingParameterValueType = (ChargingParameterValueType) o; 
        if(!(this.getValue() == chargingParameterValueType.getValue())) {
            return false;
        }
        if (this.hashCode() != chargingParameterValueType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ChargingParameterValueType

